@@ -2,7 +2,6 @@
 
 ## Setup
 library("testthat")
-library_if_available("coenocliner")
 
 ## Runs the tests in inst/tests
-test_package("coenocliner")
+test_check("coenocliner")
